@@ -26,11 +26,10 @@
 #include <iterator>
 #include <iostream>
 
+#include "modsecurity/variable_value.h"
 #include "modsecurity/modsecurity.h"
 #include "src/utils/string.h"
-#include "src/macro_expansion.h"
 #include "modsecurity/transaction.h"
-#include "modsecurity/collection/variable.h"
 #include "src/variables/variable.h"
 #include "src/variables/highest_severity.h"
 #include "src/actions/transformations/transformation.h"
@@ -279,7 +278,7 @@ int Lua::getvars(lua_State *L) {
     const char *varname = NULL;
     Transaction *t = NULL;
     void *z = NULL;
-    std::vector<const collection::Variable *> l;
+    std::vector<const VariableValue *> l;
     int idx = 1;
 
     /* Retrieve parameters. */
@@ -308,7 +307,7 @@ int Lua::getvars(lua_State *L) {
         idx++;
     }
 
-    for (const collection::Variable * i : l) {
+    for (const VariableValue * i : l) {
         delete i;
     }
 
@@ -364,8 +363,30 @@ int Lua::setvar(lua_State *L) {
         return -1;
     }
 
-    t->m_collections.storeOrUpdateFirst(collection,
-        variableName, var_value);
+    if (collection == "TX") {
+        t->m_collections.m_tx_collection->storeOrUpdateFirst(
+            "TX:" + variableName, "", var_value);
+    }
+    else if (collection == "IP") {
+        t->m_collections.m_ip_collection->storeOrUpdateFirst(
+            "IP:" + variableName, t->m_collections.m_ip_collection_key,
+            var_value);
+    }
+    else if (collection == "GLOBAL") {
+        t->m_collections.m_global_collection->storeOrUpdateFirst(
+            "GLOBAL:" + variableName, t->m_collections.m_global_collection_key,
+            var_value);
+    }
+    else if (collection == "RESOURCE") {
+        t->m_collections.m_resource_collection->storeOrUpdateFirst(
+            "RESOURCE:" + variableName,
+            t->m_collections.m_resource_collection_key, var_value);
+    }
+    else if (collection == "SESSION") {
+         t->m_collections.m_session_collection->storeOrUpdateFirst(
+            "SESSION:" + variableName, t->m_collections.m_session_collection_key,
+            var_value);
+    }
 
     return 0;
 }
