@@ -21,8 +21,10 @@
 #include <yajl/yajl_tree.h>
 #include <yajl/yajl_gen.h>
 #endif
+#ifdef WITH_LIBXML2
 #include <libxml/xmlschemas.h>
 #include <libxml/xpath.h>
+#endif
 #ifdef MSC_WITH_CURL
 #include <curl/curl.h>
 #endif
@@ -59,6 +61,7 @@ namespace modsecurity {
  */
 ModSecurity::ModSecurity()
     : m_connector(""),
+    m_whoami(""),
 #ifdef WITH_LMDB
     m_global_collection(new collection::backend::LMDB()),
     m_resource_collection(new collection::backend::LMDB()),
@@ -66,11 +69,11 @@ ModSecurity::ModSecurity()
     m_session_collection(new collection::backend::LMDB()),
     m_user_collection(new collection::backend::LMDB()),
 #else
-    m_global_collection(new collection::backend::InMemoryPerProcess()),
-    m_resource_collection(new collection::backend::InMemoryPerProcess()),
-    m_ip_collection(new collection::backend::InMemoryPerProcess()),
-    m_session_collection(new collection::backend::InMemoryPerProcess()),
-    m_user_collection(new collection::backend::InMemoryPerProcess()),
+    m_global_collection(new collection::backend::InMemoryPerProcess("GLOBAL")),
+    m_ip_collection(new collection::backend::InMemoryPerProcess("IP")),
+    m_resource_collection(new collection::backend::InMemoryPerProcess("RESOURCE")),
+    m_session_collection(new collection::backend::InMemoryPerProcess("SESSION")),
+    m_user_collection(new collection::backend::InMemoryPerProcess("USER")),
 #endif
     m_logCb(NULL) {
     UniqueId::uniqueId();
@@ -78,7 +81,9 @@ ModSecurity::ModSecurity()
 #ifdef MSC_WITH_CURL
     curl_global_init(CURL_GLOBAL_ALL);
 #endif
+#ifdef WITH_LIBXML2
     xmlInitParser();
+#endif
 }
 
 
@@ -89,8 +94,9 @@ ModSecurity::~ModSecurity() {
 #ifdef WITH_GEOIP
     Utils::GeoLookup::getInstance().cleanUp();
 #endif
+#ifdef WITH_LIBXML2
     xmlCleanupParser();
-
+#endif
     delete m_global_collection;
     delete m_resource_collection;
     delete m_ip_collection;
@@ -111,7 +117,7 @@ ModSecurity::~ModSecurity() {
  *       update it, make it in a fashion that won't break the existent parsers.
  *       (e.g. adding extra information _only_ to the end of the string)
  */
-const std::string ModSecurity::whoAmI() {
+const std::string& ModSecurity::whoAmI() {
     std::string platform("Unknown platform");
 
 #if AIX
@@ -134,8 +140,11 @@ const std::string ModSecurity::whoAmI() {
     platform = "Windows";
 #endif
 
-    return std::string("ModSecurity v" MODSECURITY_VERSION \
-        " (" + platform + ")");
+    if (m_whoami.empty()) {
+        m_whoami = "ModSecurity v" MODSECURITY_VERSION " (" + platform + ")";
+    }
+
+    return m_whoami;
 }
 
 
