@@ -32,7 +32,6 @@
 #include "src/utils/string.h"
 #include "modsecurity/rules.h"
 #include "modsecurity/rule_message.h"
-#include "src/macro_expansion.h"
 #include "src/actions/msg.h"
 #include "src/actions/log_data.h"
 #include "src/actions/severity.h"
@@ -238,19 +237,7 @@ void Rule::updateRulesVariable(Transaction *trans) {
 }
 
 
-std::string Rule::resolveMatchMessage(std::string key, std::string value) {
-    std::string ret = this->m_op->m_match_message;
 
-    if (ret.empty() == true) {
-        ret = "Matched \"Operator `" + this->m_op->m_op + "' with parameter `" +
-            utils::string::limitTo(200, this->m_op->m_param) +
-            "' against variable `" + key + "' (Value: `" +
-            utils::string::limitTo(100, utils::string::toHexIfNeeded(value)) +
-            "' )";
-    }
-
-    return ret;
-}
 
 
 void Rule::executeActionsIndependentOfChainedRuleResult(Transaction *trans,
@@ -288,9 +275,12 @@ bool Rule::executeOperatorAt(Transaction *trans, std::string key,
     bool ret;
 
 #ifndef NO_LOGS
-    trans->debug(9, "Target value: \"" + utils::string::limitTo(80,
+    if (trans && trans->m_rules && trans->m_rules->m_debugLog
+        && trans->m_rules->m_debugLog->getDebugLogLevel() >= 9) {
+        trans->debug(9, "Target value: \"" + utils::string::limitTo(80,
             utils::string::toHexIfNeeded(value)) \
             + "\" (Variable: " + key + ")");
+    }
 #endif
 
     ret = this->m_op->evaluateInternal(trans, this, value, ruleMessage);
@@ -431,14 +421,14 @@ std::list<std::pair<std::shared_ptr<std::string>,
 }
 
 
-std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
+std::vector<std::unique_ptr<VariableValue>> Rule::getFinalVars(
     Transaction *trans) {
     std::list<std::string> exclusions;
     std::list<std::string> exclusions_update_by_tag_remove;
     std::list<std::string> exclusions_update_by_msg_remove;
     std::list<std::string> exclusions_update_by_id_remove;
     std::vector<Variables::Variable *> variables;
-    std::vector<std::unique_ptr<collection::Variable>> finalVars;
+    std::vector<std::unique_ptr<VariableValue>> finalVars;
 
     std::copy(m_variables->begin(), m_variables->end(),
         std::back_inserter(variables));
@@ -449,7 +439,7 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
             continue;
         }
         if (a.second->m_isExclusion) {
-            std::vector<const collection::Variable *> z;
+            std::vector<const VariableValue *> z;
             a.second->evaluate(trans, this, &z);
             for (auto &y : z) {
                 exclusions_update_by_tag_remove.push_back(
@@ -471,7 +461,7 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
             continue;
         }
         if (a.second->m_isExclusion) {
-            std::vector<const collection::Variable *> z;
+            std::vector<const VariableValue *> z;
             a.second->evaluate(trans, this, &z);
             for (auto &y : z) {
                 exclusions_update_by_msg_remove.push_back(
@@ -493,7 +483,7 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
             continue;
         }
         if (a.second->m_isExclusion) {
-            std::vector<const collection::Variable *> z;
+            std::vector<const VariableValue *> z;
             a.second->evaluate(trans, this, &z);
             for (auto &y : z) {
                 exclusions_update_by_id_remove.push_back(std::string(y->m_key));
@@ -510,7 +500,7 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
     for (int i = 0; i < variables.size(); i++) {
         Variable *variable = variables.at(i);
         if (variable->m_isExclusion) {
-            std::vector<const collection::Variable *> z;
+            std::vector<const VariableValue *> z;
             variable->evaluate(trans, this, &z);
             for (auto &y : z) {
                 exclusions.push_back(std::string(y->m_key));
@@ -522,7 +512,7 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
 
     for (int i = 0; i < variables.size(); i++) {
         Variable *variable = variables.at(i);
-        std::vector<const collection::Variable *> e;
+        std::vector<const VariableValue *> e;
         bool ignoreVariable = false;
 
         if (variable->m_isExclusion) {
@@ -530,7 +520,7 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
         }
 
         variable->evaluate(trans, this, &e);
-        for (const collection::Variable *v : e) {
+        for (const VariableValue *v : e) {
             std::string key = v->m_key;
 
             if (std::find_if(exclusions.begin(), exclusions.end(),
@@ -658,8 +648,8 @@ std::vector<std::unique_ptr<collection::Variable>> Rule::getFinalVars(
                 continue;
             }
 
-            std::unique_ptr<collection::Variable> var(
-                new collection::Variable(v));
+            std::unique_ptr<VariableValue> var(
+                new VariableValue(v));
             delete v;
             v = NULL;
             finalVars.push_back(std::move(var));
@@ -747,7 +737,7 @@ bool Rule::evaluate(Transaction *trans,
     std::vector<Variable *> *variables = this->m_variables;
     bool recursiveGlobalRet;
     bool containsDisruptive = false;
-    std::vector<std::unique_ptr<collection::Variable>> finalVars;
+    std::vector<std::unique_ptr<VariableValue>> finalVars;
     std::string eparam;
 
     if (ruleMessage == NULL) {
@@ -776,19 +766,20 @@ bool Rule::evaluate(Transaction *trans,
         }
 #ifndef NO_LOGS
         trans->debug(9, "Rule id: " + std::to_string(m_ruleId) +
-            " was skipped due to an ruleRemoveById action...");
+            " was skipped due to a ruleRemoveById action...");
 #endif
         return true;
     }
 
-    eparam = MacroExpansion::expand(this->m_op->m_param, trans);
-
-    if (this->m_op->m_param != eparam) {
-        eparam = "\"" + eparam + "\" Was: \"" + this->m_op->m_param + "\"";
-    } else {
-        eparam = "\"" + eparam + "\"";
-    }
+    if (m_op->m_string) {
+        eparam = m_op->m_string->evaluate(trans);
 
+        if (m_op->m_string->containsMacro()) {
+            eparam = "\"" + eparam + "\" Was: \"" \
+                + m_op->m_string->evaluate(NULL) + "\"";
+        } else {
+            eparam = "\"" + eparam + "\"";
+        }
 #ifndef NO_LOGS
     trans->debug(4, "(Rule: " + std::to_string(m_ruleId) \
         + ") Executing operator \"" + this->m_op->m_op \
@@ -797,6 +788,14 @@ bool Rule::evaluate(Transaction *trans,
         + " against " \
         + Variable::to_s(variables) + ".");
 #endif
+    } else {
+#ifndef NO_LOGS
+    trans->debug(4, "(Rule: " + std::to_string(m_ruleId) \
+        + ") Executing operator \"" + this->m_op->m_op \
+        + " against " \
+        + Variable::to_s(variables) + ".");
+#endif
+    }
 
     updateRulesVariable(trans);
 
@@ -820,7 +819,8 @@ bool Rule::evaluate(Transaction *trans,
             ret = executeOperatorAt(trans, key, valueAfterTrans, ruleMessage);
 
             if (ret == true) {
-                ruleMessage->m_match = resolveMatchMessage(key, value);
+                ruleMessage->m_match = m_op->resolveMatchMessage(trans,
+                    key, value);
                 for (auto &i : v->m_orign) {
                     ruleMessage->m_reference.append(i->toText());
                 }
