@@ -203,15 +203,20 @@ int Rules::evaluate(int phase, Transaction *transaction) {
             debug(9, "Skipped rule id '" + std::to_string(rule->m_ruleId) \
                 + "'. Removed by an SecRuleRemove directive.");
         } else {
+            bool remove_rule = false;
             if (m_exceptions.m_remove_rule_by_msg.empty() == false) {
                 for (auto &z : m_exceptions.m_remove_rule_by_msg) {
                     if (rule->containsMsg(z, transaction) == true) {
                         debug(9, "Skipped rule id '" \
                             + std::to_string(rule->m_ruleId) \
                             + "'. Removed by a SecRuleRemoveByMsg directive.");
-                        return 1;
+                        remove_rule = true;
+                        break;
                     }
                 }
+                if (remove_rule) {
+                    continue;
+                }
             }
 
             if (m_exceptions.m_remove_rule_by_tag.empty() == false) {
@@ -220,9 +225,23 @@ int Rules::evaluate(int phase, Transaction *transaction) {
                         debug(9, "Skipped rule id '" \
                             + std::to_string(rule->m_ruleId) \
                             + "'. Removed by a SecRuleRemoveByTag directive.");
-                        return 1;
+                        remove_rule = true;
+                        break;
                     }
                 }
+                if (remove_rule) {
+                    continue;
+                }
+            }
+
+            for (auto &z : transaction->m_ruleRemoveByTag) {
+                if (rule->containsTag(z, transaction) == true) {
+                    debug(9, "Skipped rule id '" \
+                        + std::to_string(rule->m_ruleId) \
+                        + "'. Skipped due to a ruleRemoveByTag action.");
+                    remove_rule = true;
+                    break;
+                }
             }
 
             rule->evaluate(transaction, NULL);
