@@ -51,6 +51,7 @@
 #include "modsecurity/rule_message.h"
 #include "modsecurity/rules_properties.h"
 #include "src/actions/disruptive/allow.h"
+#include "src/variables/remote_user.h"
 
 
 
@@ -125,7 +126,11 @@ Transaction::Transaction(ModSecurity *ms, Rules *rules, void *logCbData)
 #else
     m_json(NULL),
 #endif
+#ifdef WITH_LIBXML2
     m_xml(new RequestBodyProcessor::XML(this)),
+#else
+    m_xml(NULL),
+#endif
     TransactionAnchoredVariables(this) {
     m_id = std::to_string(this->m_timeStamp) + \
         std::to_string(modsecurity::utils::generate_transaction_unique_id());
@@ -158,7 +163,9 @@ Transaction::~Transaction() {
 #ifdef WITH_YAJL
     delete m_json;
 #endif
+#ifdef WITH_LIBXML2
     delete m_xml;
+#endif
 }
 
 
@@ -665,6 +672,7 @@ int Transaction::processRequestBody() {
      */
     std::unique_ptr<std::string> a = m_variableRequestHeaders.resolveFirst(
         "Content-Type");
+#ifdef WITH_LIBXML2
     if (m_requestBodyProcessor == XMLRequestBody) {
         std::string error;
         if (m_xml->init() == true) {
@@ -684,8 +692,13 @@ int Transaction::processRequestBody() {
             m_variableReqbodyError.set("0", m_variableOffset);
             m_variableReqbodyProcessorError.set("0", m_variableOffset);
         }
+#endif
 #if WITH_YAJL
+#ifdef WITH_LIBXML2
     } else if (m_requestBodyProcessor == JSONRequestBody) {
+#else
+    if (m_requestBodyProcessor == JSONRequestBody) {
+#endif
         std::string error;
         if (m_json->init() == true) {
             m_json->processChunk(m_requestBody.str().c_str(),
@@ -705,7 +718,11 @@ int Transaction::processRequestBody() {
             m_variableReqbodyProcessorError.set("0", m_variableOffset);
         }
 #endif
+#if defined(WITH_LIBXML2) or defined(WITH_YAJL)
     } else if (m_requestBodyType == MultiPartRequestBody) {
+#else
+    if (m_requestBodyType == MultiPartRequestBody) {
+#endif
         std::string error;
         if (a != NULL) {
             Multipart m(*a, this);
@@ -783,7 +800,7 @@ int Transaction::processRequestBody() {
      * computationally intensive.
      */
     std::string fullRequest;
-    std::vector<const collection::Variable *> l;
+    std::vector<const VariableValue *> l;
     m_variableRequestHeaders.resolve(&l);
     for (auto &a : l) {
         std::string z(a->m_key, 16, a->m_key.length() - 16);
@@ -1367,14 +1384,19 @@ std::string Transaction::toOldAuditLogFormatIndex(const std::string &filename,
         << " ";
     ss << utils::string::dash_if_empty(this->m_clientIpAddress.c_str()) << " ";
     /** TODO: Check variable */
+    Variables::RemoteUser *r = new Variables::RemoteUser("REMOTE_USER");
+    std::vector<const VariableValue *> l;
+    r->evaluate(this, NULL, &l);
+    delete r;
+
     ss << utils::string::dash_if_empty(
-        m_collections.resolveFirst("REMOTE_USER").get());
+        m_variableRemoteUser.c_str());
     ss << " ";
     /** TODO: Check variable */
-    ss << utils::string::dash_if_empty(
-        this->m_collections.resolveFirst("LOCAL_USER").get());
-    ss << " ";
-    ss << tstr << " ";
+    //ss << utils::string::dash_if_empty(
+    //    this->m_collections.resolveFirst("LOCAL_USER").get());
+    //ss << " ";
+    //ss << tstr << " ";
 
     ss << "\"";
     ss << utils::string::dash_if_empty(m_variableRequestMethod.evaluate());
@@ -1387,7 +1409,7 @@ std::string Transaction::toOldAuditLogFormatIndex(const std::string &filename,
     ss << this->m_responseBody.tellp() << " ";
     /** TODO: Check variable */
     ss << utils::string::dash_if_empty(
-        this->m_collections.resolveFirst("REFERER").get()) << " ";
+        m_variableRequestHeaders.resolveFirst("REFERER").get()) << " ";
     ss << "\"";
     ss << utils::string::dash_if_empty(
         m_variableRequestHeaders.resolveFirst("User-Agent").get());
@@ -1395,7 +1417,7 @@ std::string Transaction::toOldAuditLogFormatIndex(const std::string &filename,
     ss << this->m_id << " ";
     /** TODO: Check variable */
     ss << utils::string::dash_if_empty(
-        this->m_collections.resolveFirst("REFERER").get()) << " ";
+        m_variableRequestHeaders.resolveFirst("REFERER").get()) << " ";
 
     ss << filename << " ";
     ss << "0" << " ";
@@ -1426,7 +1448,7 @@ std::string Transaction::toOldAuditLogFormat(int parts,
     audit_log << std::endl;
 
     if (parts & audit_log::AuditLog::BAuditLogPart) {
-        std::vector<const collection::Variable *> l;
+        std::vector<const VariableValue *> l;
         audit_log << "--" << trailer << "-" << "B--" << std::endl;
         audit_log << utils::string::dash_if_empty(
             m_variableRequestMethod.evaluate());
@@ -1466,7 +1488,7 @@ std::string Transaction::toOldAuditLogFormat(int parts,
         audit_log << std::endl;
     }
     if (parts & audit_log::AuditLog::FAuditLogPart) {
-        std::vector<const collection::Variable *> l;
+        std::vector<const VariableValue *> l;
 
         audit_log << "--" << trailer << "-" << "F--" << std::endl;
         audit_log << "HTTP/" << m_httpVersion.c_str()  << " ";
@@ -1566,7 +1588,7 @@ std::string Transaction::toJSON(int parts) {
 
     /* request headers */
     if (parts & audit_log::AuditLog::BAuditLogPart) {
-        std::vector<const collection::Variable *> l;
+        std::vector<const VariableValue *> l;
         yajl_gen_string(g, reinterpret_cast<const unsigned char*>("headers"),
             strlen("headers"));
         yajl_gen_map_open(g);
@@ -1597,7 +1619,7 @@ std::string Transaction::toJSON(int parts) {
 
     /* response headers */
     if (parts & audit_log::AuditLog::FAuditLogPart) {
-        std::vector<const collection::Variable *> l;
+        std::vector<const VariableValue *> l;
         yajl_gen_string(g, reinterpret_cast<const unsigned char*>("headers"),
             strlen("headers"));
         yajl_gen_map_open(g);
