@@ -35,7 +35,7 @@ class Env : public Variable {
 
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) override;
+        std::vector<const VariableValue *> *l) override;
 };
 
 
