@@ -38,7 +38,7 @@ class FilesNames_DictElement : public Variable {
 
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) override {
+        std::vector<const VariableValue *> *l) override {
         transaction->m_variableFilesNames.resolve(m_dictElement, l);
     }
 
@@ -53,7 +53,7 @@ class FilesNames_NoDictElement : public Variable {
 
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) override {
+        std::vector<const VariableValue *> *l) override {
         transaction->m_variableFilesNames.resolve(l);
     }
 };
@@ -68,7 +68,7 @@ class FilesNames_DictElementRegexp : public Variable {
 
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) override {
+        std::vector<const VariableValue *> *l) override {
         transaction->m_variableFilesNames.resolveRegularExpression(
             &m_r, l);
     }
