@@ -35,7 +35,7 @@ class MultipartInvalidQuoting : public Variable {
         : Variable("MULTIPART_INVALID_QUOTING") { }
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         transaction->m_variableMultipartInvalidQuoting.evaluate(l);
     }
 };
