@@ -36,7 +36,7 @@ class MultipartStrictError : public Variable {
 
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         transaction->m_variableMultipartStrictError.evaluate(l);
     }
 };
