@@ -35,7 +35,7 @@ class RequestBody : public Variable {
         : Variable("REQUEST_BODY") { }
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         transaction->m_variableRequestBody.evaluate(l);
     }
 };
