@@ -35,7 +35,7 @@ class RequestBodyLength : public Variable {
         : Variable("REQUEST_BODY_LENGTH") { }
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         transaction->m_variableRequestBodyLength.evaluate(l);
     }
 };
