@@ -35,7 +35,7 @@ class RequestLine : public Variable {
         : Variable("REQUEST_LINE") { }
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         transaction->m_variableRequestLine.evaluate(l);
     }
 };
