@@ -35,7 +35,7 @@ class RequestURIRaw : public Variable {
         : Variable("REQUEST_URI_RAW") { }
     void evaluate(Transaction *transaction,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         transaction->m_variableRequestURIRaw.evaluate(l);
     }
 };
