@@ -18,9 +18,11 @@
 #include <list>
 #include <utility>
 #include <memory>
+#include <exception>
 
 #include "modsecurity/transaction.h"
 #include "modsecurity/rule.h"
+#include "modsecurity/rules.h"
 #include "src/utils/string.h"
 #include "src/utils/regex.h"
 
@@ -32,47 +34,15 @@ namespace modsecurity {
 class Transaction;
 namespace Variables {
 
+
 class Variable {
  public:
-    /**
-     *
-     */
-    enum VariableType {
-      /**
-       *
-       */
-      SingleMatch,
-      /**
-       *
-       */
-      MultipleMatches,
-      /**
-       *
-       */
-      RegularExpression
-    };
-
-    /**
-     *
-     */
-    enum VariableKind {
-      /**
-       *
-       */
-      DirectVariable,
-      /**
-       *
-       */
-      CollectionVarible,
-    };
-
     explicit Variable(std::string _name);
-    Variable(std::string name, VariableKind kind);
     virtual ~Variable() { }
 
     virtual void evaluate(Transaction *t,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) = 0;
+        std::vector<const VariableValue *> *l) = 0;
 
     static std::string to_s(std::vector<Variable *> *variables);
 
@@ -86,7 +56,7 @@ class Variable {
 
     static void stringMatchResolveMulti(Transaction *t,
         const std::string &variable,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         size_t collection = variable.find(".");
         if (collection == std::string::npos) {
             collection = variable.find(":");
@@ -191,7 +161,7 @@ class Variable {
             } else if (comp(variable, "USERID")) {
                 t->m_variableUserID.evaluate(l);
             } else {
-                t->m_collections.resolveMultiMatches(variable, l);
+                throw std::invalid_argument("Variable not found.");
             }
         } else {
             std::string col = std::string(variable, 0, collection);
@@ -218,9 +188,9 @@ class Variable {
             } else if (comp(col, "FILES_TMP_CONTENT")) {
                 t->m_variableFilesTmpContent.resolve(var, l);
             } else if (comp(col, "MULTIPART_FILENAME")) {
-                t->m_variableMultiPartFileName.resolve(var, l);
+                t->m_variableMultipartFileName.resolve(var, l);
             } else if (comp(col, "MULTIPART_NAME")) {
-                t->m_variableMultiPartName.resolve(var, l);
+                t->m_variableMultipartName.resolve(var, l);
             } else if (comp(col, "MATCHED_VARS_NAMES")) {
                 t->m_variableMatchedVarsNames.resolve(var, l);
             } else if (comp(col, "MATCHED_VARS")) {
@@ -244,7 +214,7 @@ class Variable {
             } else if (comp(col, "FILES_TMPNAMES")) {
                 t->m_variableFilesTmpNames.resolve(var, l);
             } else {
-                t->m_collections.resolveMultiMatches(col, var, l);
+                throw std::invalid_argument("Variable not found.");
             }
         }
     }
@@ -355,8 +325,25 @@ class Variable {
                 vv = t->m_variableUrlEncodedError.resolveFirst();
             } else if (comp(variable, "USERID")) {
                 vv = t->m_variableUserID.resolveFirst();
+            } else if (comp(variable, "TX")) {
+                vv = t->m_collections.m_tx_collection->resolveFirst("");
+            } else if (comp(variable, "RESOURCE")) {
+                vv = t->m_collections.m_resource_collection->resolveFirst("",
+                    t->m_collections.m_resource_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(variable, "USER")) {
+                vv = t->m_collections.m_user_collection->resolveFirst("",
+                    t->m_collections.m_user_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(variable, "SESSION")) {
+                vv = t->m_collections.m_session_collection->resolveFirst("",
+                    t->m_collections.m_session_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(variable, "IP")) {
+                vv = t->m_collections.m_ip_collection->resolveFirst("",
+                    t->m_collections.m_ip_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(variable, "GLOBAL")) {
+                vv = t->m_collections.m_global_collection->resolveFirst("",
+                    t->m_collections.m_global_collection_key, t->m_rules->m_secWebAppId.m_value);
             } else {
-                vv = t->m_collections.resolveFirst(variable);
+                throw std::invalid_argument("Variable not found.");
             }
         } else {
             std::string col = std::string(variable, 0, collection);
@@ -383,9 +370,9 @@ class Variable {
             } else if (comp(col, "FILES_TMP_CONTENT")) {
                 vv = t->m_variableFilesTmpContent.resolveFirst(var);
             } else if (comp(col, "MULTIPART_FILENAME")) {
-                vv = t->m_variableMultiPartFileName.resolveFirst(var);
+                vv = t->m_variableMultipartFileName.resolveFirst(var);
             } else if (comp(col, "MULTIPART_NAME")) {
-                vv = t->m_variableMultiPartName.resolveFirst(var);
+                vv = t->m_variableMultipartName.resolveFirst(var);
             } else if (comp(col, "MATCHED_VARS_NAMES")) {
                 vv = t->m_variableMatchedVarsNames.resolveFirst(var);
             } else if (comp(col, "MATCHED_VARS")) {
@@ -408,18 +395,37 @@ class Variable {
                 vv = t->m_variableRequestCookiesNames.resolveFirst(var);
             } else if (comp(col, "FILES_TMPNAMES")) {
                 vv = t->m_variableFilesTmpNames.resolveFirst(var);
+            } else if (comp(col, "TX")) {
+                vv = t->m_collections.m_tx_collection->resolveFirst(var);
+            } else if (comp(col, "RESOURCE")) {
+                vv = t->m_collections.m_resource_collection->resolveFirst(var,
+                    t->m_collections.m_resource_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(col, "USER")) {
+                vv = t->m_collections.m_user_collection->resolveFirst(var,
+                    t->m_collections.m_user_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(col, "SESSION")) {
+                vv = t->m_collections.m_session_collection->resolveFirst(var,
+                    t->m_collections.m_session_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(col, "IP")) {
+                vv = t->m_collections.m_ip_collection->resolveFirst(var,
+                    t->m_collections.m_ip_collection_key, t->m_rules->m_secWebAppId.m_value);
+            } else if (comp(col, "GLOBAL")) {
+                vv = t->m_collections.m_global_collection->resolveFirst(var,
+                    t->m_collections.m_global_collection_key, t->m_rules->m_secWebAppId.m_value);
             } else {
-                vv = t->m_collections.resolveFirst(col, var);
+                throw std::invalid_argument("Variable not found.");
             }
         }
+        if (vv == nullptr) {
+            return std::string("");
+        }
         return std::string(*vv.get());
     }
 
     std::string m_name;
     std::string m_collectionName;
+    std::shared_ptr<std::string> m_fullName;
 
-    VariableType m_type;
-    VariableKind m_kind;
     bool m_isExclusion;
     bool m_isCount;
 };
@@ -428,14 +434,14 @@ class Variable {
 class VariableModificatorExclusion : public Variable {
  public:
     explicit VariableModificatorExclusion(std::unique_ptr<Variable> var)
-        : Variable(var->m_name),
+        : Variable(*var->m_fullName.get()),
         m_var(std::move(var)) {
             m_isExclusion = true;
         }
 
     void evaluate(Transaction *t,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
+        std::vector<const VariableValue *> *l) {
         m_var->evaluate(t, rule, l);
     }
 
@@ -446,30 +452,28 @@ class VariableModificatorExclusion : public Variable {
 class VariableModificatorCount : public Variable {
  public:
     explicit VariableModificatorCount(std::unique_ptr<Variable> var)
-        : Variable(var->m_name),
+        : Variable(*var->m_fullName.get()),
         m_var(std::move(var)) {
             m_isCount = true;
         }
 
     void evaluate(Transaction *t,
         Rule *rule,
-        std::vector<const collection::Variable *> *l) {
-        std::vector<const collection::Variable *> reslIn;
-        collection::Variable *val = NULL;
+        std::vector<const VariableValue *> *l) {
+        std::vector<const VariableValue *> reslIn;
+        VariableValue *val = NULL;
         int count = 0;
 
         m_var->evaluate(t, rule, &reslIn);
-        for (const collection::Variable *a : reslIn) {
+        for (const VariableValue *a : reslIn) {
             count++;
-	    delete a;
+            delete a;
             a = NULL;
         }
         reslIn.clear();
 
         std::string *res = new std::string(std::to_string(count));
-        std::string *name = new std::string(m_name);
-        val = new collection::Variable(name, res);
-        delete name;
+        val = new VariableValue(m_var->m_fullName, res);
         delete res;
 
         l->push_back(val);
